pub(crate) fn main()Expand description
Main handles argument parsing and calling the necessary submodules.
The main function takes the following arguments:
-h, –help Print this help message and exit
-s, –server Run in Server mode
-d, –dummy Run in Dummy Server mode
-a, –archive Run in Archiver mode\
Server Mode
Sources real radar data and sends it to the DATA_ADDRESS.
ToDo: needs to be implemented
Dummy Mode
Sources simulated radar data and sends it to the DATA_ADDRESS.
Archive Mode
Sources radar packets from the SUBSCRIPTION_ADDRESS, archives each packet and forwards the live data the DATA_ADDRESS. Additionally will send archived data to individual clients on request.
ToDo: Sending archived data as well as forwarding live data is not yet implemented